# NetworkManager

## Python dependencies

- pydantic
- dbus-python

**To install `dbus-python` you need runtime dependency of `libdbus-1-dev` and `libglib2.0-dev`**

## Hotspot

To run hotspot you need `dnsmasq` DHCP server.
